========
Elements
========

Documents are wrapped by ``content`` class of Bulma by ``bulma-basic`` theme.
Some elements render as Bulma designed style.

Definition lists
================

term (up to a line of text)
   Definition of the term, which must be indented

Table
=====

.. note:: Tables are translated to add ``table`` class for design.

.. csv-table::
   :header: Name,Description

   toybox, Misc items.
   bulma, Bulma components and theme.

Field lists
===========

:fieldname: Field content

Footnotes
=========

.. note:: Style of footnotes is updated to adjust for other elements.


Lorem ipsum [#f1]_ dolor sit amet ... [#f2]_

.. rubric:: Footnotes

.. [#f1] Text of the first footnote.
.. [#f2] Text of the second footnote.

